clear
set more off
for X in numlist 1024(25)1300 : capture set mem Xm
forvalues X = 5000(500)8000 {
	capture set maxvar X
	sleep 250
}
for X in numlist 4000(500)20000 : capture set mat X
cd "C:\Users\James\Dropbox\Research\Solo\Land Abundance\Replication Files\"

use fenskelandabundancedata, clear

***** Specifications
*****
*****

***Define Sample
gen sample=landqualnumber~=0 & date>1499
	/*Drops mostly pacific islands too small to intersect FAO data*/
keep if sample==1

***Controls and choice of instrument
global dummycontrols river 
global continuouscontrols landquality rain atemp date shdesert distcoast ///
	elevation malaria ruggedness abslat raincv
global controls $continuouscontrols $dummycontrols 
global rmcontrols rmlandquality rmrain rmatemp rmdate rmshdesert ///
	rmdistcoast rmelevation rmmalaria rmruggedness rmabslat ///
	rmraincv rmriver 
global controlsnoabslat landquality rain atemp date shdesert distcoast ///
	elevation malaria ruggedness raincv river
global continents medit easteurasia pacific namerica samerica

***Prepare Conley's logit
cap program drop xgmlt
cap program drop x_ols
do "http://economics.uwo.ca/faculty/conley/data_GMMWithCross_99/xgmlt.ado"
do "http://economics.uwo.ca/faculty/conley/data_GMMWithCross_99/x_ols.ado"

cap drop cutoff1 cutoff2
gen cutoff1=10
gen cutoff2=cutoff1

***A program that is needed for computing marginal effects
capture program drop newcov
	program define newcov, eclass
	ereturn repost V=cov_dep
end

***Automate reporting of results
*Conley's logit
cap program drop conleylogitmfx
program define conleylogitmfx
	args depvar outfile ncont
	preserve
		keep if `depvar'~=.
		qui xgmlt latitude longitude cutoff1 cutoff2 `depvar' $currentcontrols const, xreg(`ncont') coord(2)
		qui glm `depvar' $currentcontrols const, family(binomial) link(logit)
		newcov
		mfx 
		outreg2 using `outfile', mfx $outopts append
	restore
end

*Conley's OLS
cap program drop conleyols
program define conleyols
	args depvar outfile ncont
	preserve
		ereturn clear
		cap drop epsilon window dis1 dis2
		qui x_ols latitude longitude cutoff1 cutoff2 `depvar' $currentcontrols constant, xreg(`ncont') coord(2)
		qui ivreg2 `depvar' $currentcontrols constant, noc 
		newcov
		estimates replay	
		outreg2 using `outfile', $outopts append  
	restore
end

***Table formatting
global outopts dec(3) label nocons excel ctitle(" ") cttop(" ") nonotes

***** Controls that must be computed from the defined sample
*****

*Population Bins
mkspline lqspline 10 = landquality
mkspline popdspline 10 = histpopd

*Generate region means for each variable
cap drop rm*
foreach var in soildepth soilfert ramank popweightedlandquality $controls ///
	suit29 suit30 suit31 suit32 suit33 suit34 suit35 suit36 ///
	anyland anyslave logpopd {
	local lvar : variable label `var'
	bysort regionminor : egen rm`var'=mean(`var')
	label var rm`var' "Region Mean: `lvar'"
	}

save fenskelandabundancedata_mainsample, replace

*Normalize the landquality variable and the controls
foreach var in landquality soildepth soilfert ramank popweightedlandquality $continuouscontrols ///
	suit29 suit30 suit31 suit32 suit33 suit34 suit35 suit36 ///
	rmsoildepth rmsoilfert rmramank rmpopweightedlandquality $rmcontrols ///
	rmsuit29 rmsuit30 rmsuit31 rmsuit32 rmsuit33 rmsuit34 rmsuit35 rmsuit36{
	egen mean`var'=mean(`var')
	egen sd`var'=sd(`var')
	replace `var'=(`var'-mean`var')/(sd`var')
	drop mean`var' sd`var'
	}

save fenskelandabundancedata_normalized, replace
