****** GLSS 5
******
******

*GLSS 5
/*Individual Characteristics*/
use sec1.dta, clear 
decode s1q13, gen(ethnicity)
keep clust hhid pid ethnicity s1q2 s1q3 s1q5y s1q24
	rename s1q2 male
		recode male (2=0)
		label var male "Plot controller male"
	rename s1q3 reltohead 
		label var reltohead "Relationship to head"
	rename s1q5y age
		label var age "Age"
		genl age2=age^2, l(Age sqrd.)
	rename s1q24 hhmember
		recode hhmember (2=0)
		label var hhmember  "HH Member"
	label var ethnicity "Ethnicity"
		replace ethnicity=proper(trim(ethnicity))
		replace ethnicity="Missing" if ethnicity==""

sort clust hhid pid
save jamestemp, replace

/*Land tenure variables*/
use sec8b, clear 
keep clust hhid region ez nh s8bq1 s8bq4a s8bq4b  s8bq6 s8bq8
	rename s8bq1 pid
	rename s8bq4a area
		label var area "Area"
		replace area=area*1 if s8bq4b==2 				
		/*Poles: 1 to 1 according to http://siteresources.worldbank.org/INTLSMS/Resources/3358986-1181743055198/3877319-1190226677657/GHA01.pdf*/
		replace area=area/10 if s8bq4b==3 	
		/*Ropes: 10 ropes = 1 acre (http://www.fao.org/docrep/006/y5026e/y5026e0a.htm) */
		replace area=. if s8bq4b==4 		/*Plot*/
		replace area=. if s8bq4b==45 		/*Other*/
		genl area2=area^2, l(Area sqrd.)
	rename s8bq4b unitofarea
		label var unitofarea "Area Units"
	rename s8bq6 rights
		genl cansell=(rights==1 | rights==3) if rights~=., l(Right to sell)
		genl cancollateral=(rights==2 | rights==3) if rights~=., l(Right to use as collateral)
		genl canboth=(rights==3) if rights~=., l(Right to sell and use as collateral)
	rename s8bq8 howacquired
		genl acqbought=howacquired==1 if howacquired~=., l(Acquisition: Bought)
		genl acqrented=howacquired==2 if howacquired~=., l(Acquisition: Rented)
		genl acqsharec=howacquired==3 if howacquired~=., l(Acquisition: Sharecropped)
		genl acqfreeus=howacquired==4 if howacquired~=., l(Acquisition: Use free of charge)
		genl acqfamily=howacquired==5 if howacquired~=., l(Acquisition: Distributed by village or family)
sort clust hhid pid
merge clust hhid pid using jamestemp
keep if _merge==3
drop _merge
save jamestemp, replace

insheet using glsstomurdock.csv, n clear
sort ethnicity
save jamestemp2, replace
use jamestemp, replace
sort ethnicity
merge ethnicity using jamestemp2
label var nameinmurdock "Name in Eth. Atlas
label var iso "Ethnologue language code"
drop _merge 
cap drop v4 v5
save jamestemp, replace

**Load and clean raw Eth Atlas data				
use ethatlas, clear 
gen nameinmurdock=proper(trim(subinstr(V107,"."," ",.)))
label var nameinmurdock "Name in Eth. Atlas"
genl anylandrights=V74>1 if V74~=0 & V74~=., l(Any land rights)
genl landpatri=V74==7 | V74==6 if V74~=0 & V74~=., l(Patrilineal land inheritance)
genl landchildren=V74==7 | V74==4 | V74==5 if V74~=0 & V74~=., l(Children inherit land)
keep nameinmurdock anylandrights landpatri landchildren
sort nameinmurdock
save jamestemp2, replace
use jamestemp, replace
sort nameinmurdock 
merge nameinmurdock using jamestemp2, _merge(mergetomurdock)
drop if mergetomurdock==2

**Get coordinates from constructed data
save jamestemp, replace
use fenskelandabundancedata, clear
keep nameinatlas latitude longitude
rename nameinatlas nameinmurdock 
sort nameinmurdock 
save jamestemp2, replace
use jamestemp, replace
sort nameinmurdock 
merge nameinmurdock using jamestemp2, _merge(mergetocoords)
drop if mergetocoords==2

**Labels and other variables
label var clust "Cluster ID"
label var hhid "Household ID"
label var region "Region"
label var ez "Ecological Zone"
label var nh "Household Number"
label var pid "Person ID" 
label var rights "Land Rights"
label var howacquired "How land acquired"

***Regression
global outopts dec(3) label nocons excel ctitle(" ") cttop(" ") nonotes
xi, pref(rdum) i.reltohead
xi, pref(edum) i.ez
xi, pref(rid) i.region
global glsscontrols area area2 male age age2 hhmember rdum* edum* rid*

cap erase glss.xml
cap erase glss_altcluster.xml
foreach rightsmeasure in acqbought acqrented acqsharec acqfamily {
foreach ethmeasure in landpatri landchildren {
reg `rightsmeasure' `ethmeasure' $glsscontrols, cl(nameinmurdock)
	outreg2 using glss, $outopts ///  
	addtext(Dep. Var, `rightsmeasure') append
reg `rightsmeasure' `ethmeasure' $glsscontrols, cl(region)
	outreg2 using glss_altcluster, br $outopts ///  
	addtext(Dep. Var, `rightsmeasure') append
}
}
cap erase glss.txt
cap erase glss_altcluster.txt

***** Clean up
*****
cap erase jamestemp.dta
cap erase jamestemp2.dta
cap erase jamestemp3.dta

